@@ -29,6 +29,7 @@ import logging
 from pathlib import Path
 
 import numpy as np
+from scipy.integrate import trapezoid
 
 LOG = logging.getLogger(__name__)
 
@@ -121,9 +122,9 @@ class SolarIrradianceSpectrum(object):
     def solar_constant(self):
         """Calculate the solar constant."""
         if self.wavenumber is not None:
-            return np.trapz(self.irradiance, self.wavenumber)
+            return trapezoid(self.irradiance, self.wavenumber)
         if self.wavelength is not None:
-            return np.trapz(self.irradiance, self.wavelength)
+            return trapezoid(self.irradiance, self.wavelength)
 
         raise TypeError('Neither wavelengths nor wavenumbers available!')
 
@@ -204,10 +205,10 @@ class SolarIrradianceSpectrum(object):
 
         # Calculate the solar-flux: (w/m2)
         if flux:
-            return np.trapz(irr * resp_ipol, wvl)
+            return trapezoid(irr * resp_ipol, wvl)
 
         # Divide by the equivalent band width:
-        return np.trapz(irr * resp_ipol, wvl) / np.trapz(resp_ipol, wvl)
+        return trapezoid(irr * resp_ipol, wvl) / trapezoid(resp_ipol, wvl)
 
     def interpolate(self, **options):
         """Interpolate Irradiance to a specified evenly spaced resolution/grid.
