@@ -21,6 +21,7 @@
 
 import logging
 import os
+import sys
 import tarfile
 import warnings
 from functools import wraps
@@ -28,6 +29,7 @@ from inspect import getfullargspec
 
 import numpy as np
 import requests
+from scipy.integrate import trapezoid
 
 from pyspectral.bandnames import BANDNAMES
 from pyspectral.config import get_config
@@ -80,6 +82,7 @@ INSTRUMENTS = {'Envisat': 'aatsr',
                'EOS-Terra': 'modis',
                'Sentinel-2A': 'msi',
                'Sentinel-2B': 'msi',
+               'Sentinel-2C': 'msi',
                'Arctica-M-N1': 'msu-gsa',
                'Electro-L-N2': 'msu-gs',
                'Sentinel-3A': ['olci', 'slstr'],
@@ -105,10 +108,11 @@ INSTRUMENT_TRANSLATION_DASH2SLASH = {'avhrr-1': 'avhrr/1',
                                      'avhrr-2': 'avhrr/2',
                                      'avhrr-3': 'avhrr/3'}
 
-HTTP_PYSPECTRAL_RSR = "https://zenodo.org/records/12743289/files/pyspectral_rsr_data.tgz"
+HTTP_PYSPECTRAL_RSR = "https://zenodo.org/records/13833977/files/pyspectral_rsr_data.tgz"
 
 RSR_DATA_VERSION_FILENAME = "PYSPECTRAL_RSR_VERSION"
-RSR_DATA_VERSION = "v1.3.2"
+RSR_DATA_VERSION = "v1.4.0"
+
 
 ATM_CORRECTION_LUT_VERSION = {}
 ATM_CORRECTION_LUT_VERSION['antarctic_aerosol'] = {'version': 'v1.0.1',
@@ -224,7 +228,7 @@ def get_central_wave(wav, resp, weight=1.0):
     # if info['unit'].find('-1') > 0:
     # Wavenumber:
     #     res *=
-    return np.trapz(resp * wav * weight, wav) / np.trapz(resp * weight, wav)
+    return trapezoid(resp * wav * weight, wav) / trapezoid(resp * weight, wav)
 
 
 def get_bandname_from_wavelength(sensor, wavelength, rsr, epsilon=0.1, multiple_bands=False):
@@ -413,7 +417,8 @@ def _download_tarball_and_extract(tarball_url, local_pathname, extract_dir):
             handle.write(data)
 
     tar = tarfile.open(local_pathname)
-    tar.extractall(extract_dir)
+    tar_kwargs = {} if sys.version_info < (3, 12) else {"filter": "data"}
+    tar.extractall(extract_dir, **tar_kwargs)
     tar.close()
     os.remove(local_pathname)
 
